@@ -1,17 +1,17 @@
-use pest::{Parser, RuleType};
+use pest::Parser;
 use std::fs::read_to_string;
 use symparser::v6::{Rule, SymParser};
 
 #[test]
 fn parse_001() {
     let string = read_to_string("examples/example_002.sym").unwrap();
-    let _pairs = SymParser::parse(Rule::sym, &string).unwrap();
+    let _pairs = SymParser::parse(Rule::main, &string).unwrap();
 }
 
 #[test]
 fn parse_002() {
     let string = read_to_string("examples/example_002.sym").unwrap();
-    let mut pairs = SymParser::parse(Rule::sym, &string).unwrap().into_iter();
+    let mut pairs = SymParser::parse(Rule::main, &string).unwrap().into_iter();
     assert_eq!(pairs.next().is_some(), true);
     assert_eq!(pairs.next().is_some(), false);
 }
